@@ -57,6 +57,25 @@ def grouping_data(processed_data, pick_vars=None):
     return data_animal_id_groups
 
 
+def timewise_dict(data):
+    """
+    Group records by timestep.
+    :param data: pd.DataFrame with all preprocessed records.
+    :return: dictionary with 'time' as key and all animal records as value.
+    """
+    # Input grouped into time
+    data_time = data.groupby('time')
+
+    # Pour into dictionary to hold data by time
+    dict_time = {}
+
+    for time in data_time.groups.keys():
+        dict_time[time] = data_time.get_group(time)
+        dict_time[time].reset_index(drop=True, inplace=True)
+
+    return dict_time
+
+
 def regrouping_data(data_animal_id_groups):
     """
     Concatenate all Pandas DataFrames in grouped dictionary into one.
@@ -130,29 +149,37 @@ def compute_distance_and_direction(data_animal_id_groups):
     :param data_animal_id_groups: dictionary ordered by 'animal_id'.
     :return: dictionary containing computed 'distance' and 'direction' attributes.
     """
+
     # Compute 'direction' for 'animal_id' groups-
     for aid in data_animal_id_groups.keys():
+        data = []
         try:
-            data_animal_id_groups[aid]['direction'] = np.rad2deg(
+            data = np.rad2deg(
                 np.arctan2((data_animal_id_groups[aid]['y'] -
                             data_animal_id_groups[aid]['y'].shift(periods=1)),
                            (data_animal_id_groups[aid]['x'] -
                             data_animal_id_groups[aid]['x'].shift(periods=1))))
         except TypeError:
-            data_animal_id_groups[aid]['direction'] = 0
+            data = 0
+
+        data_animal_id_groups[aid] = data_animal_id_groups[aid].assign(
+            direction=data)
 
     # Compute 'distance' for 'animal_id' groups-
     for aid in data_animal_id_groups.keys():
+        data = []
         try:
             p1 = data_animal_id_groups[aid].loc[:, ['x', 'y']]
             p2 = data_animal_id_groups[aid].loc[:, ['x', 'y']].shift(periods=1)
             p2.iloc[0, :] = [0.0, 0.0]
 
-            data_animal_id_groups[aid]['distance'] = ((p1 -
-                                                       p2)**2).sum(axis=1)**0.5
+            data = ((p1 - p2)**2).sum(axis=1)**0.5
 
         except TypeError:
-            data_animal_id_groups[aid]['distance'] = 0
+            data = 0
+
+        data_animal_id_groups[aid] = data_animal_id_groups[aid].assign(
+            distance=data)
 
     # Reset first entry for each 'animal_id' to zero-
     for aid in data_animal_id_groups.keys():
